# Changelog

## 0.0.5

More community fixes, including the Community Title Property

## 0.0.4

Small community fixes

## 0.0.3

Working on bridge api

## 0.0.2

Rebranded to Nectar

## 0.0.1

- Initial release
- Beem stops and Nectar starts
